@@ -150,7 +150,10 @@ class Gui(abstract.IntervalGui):
             if not self.m_t.m_tonika:
                 return
             i = mpd.Interval()
-            i.set_from_int(interval)
+            if self.m_t.m_question[0] < 0:
+                i.set_from_int(-interval)
+            else:
+                i.set_from_int(interval)
             n = self.m_t.m_tonika + i
             track = utils.new_track()
             track.note(4, self.m_t.m_tonika.semitone_pitch())
