@@ -87,11 +87,6 @@ class PercentagesTable(gtk.Frame):
             for o in box.get_children():
                 o.destroy()
         for k in statistics.get_keys():
-            # FIXME  Has this bug been fixed? This should NEVER happen.
-            if k is None:
-                print "WARNING: statistics: key==None. Please, please report to"
-                print "bug-solfege@gnu.org if you get this message. Preferably,"
-                print "make a copy ~/.solfege so I can debug this."
             l = lessonfilegui.new_labelobject(statistics.key_to_pretty_name(k))
             l.set_alignment(0.0, 0.5)
             self.boxdict['keys'].pack_start(l)
